Learn R Programming

BioPhysConnectoR (version 1.6-7)

scpcp: Self-Consistent Pair Contact Probability Approximation

Description

The model of the Self-Consistent Pair Contact Probability (SCPCP) (Micheletti et al., 2001; Hamacher et al., 2006) computes equilibrium properties of structures with known native states. For a given contact map, extracted from a PDB file or artificially created, the fraction of native contacts, the free and internal energies are computed as well as the degree to which an amino acid is in its native state conformation. The maximum number of iteration and the preferred accuracy for the approximation can be specified.

Usage

scpcp(T, R, cm, pstart = 0.5, maxiter = 2000, chains=NULL, maxtol = 1e-11,
      file = NULL, im = NULL)

Arguments

T
temperature
R
distance cutoff between current and native state
cm
contact map
pstart
initial probability value
chains
vector denoting the chain lengths
maxiter
maximum number of iterations
maxtol
tolerance
file
output file name
im
interaction matrix

Value

  • Returns a list with the following components
  • $freefree energy
  • $interninternal energy
  • $entropyentropy
  • $qfraction of native contacts
  • $bfacsvector containing the B factors
  • $piprobability vector
  • $gmatresulting G matrix
  • $iternumber of iterations
  • $errdeviation of probabilities

Details

Results of each iteration as well as the final results are written into the given output file.

References

Micheletti, Banavar, Maritan (2001) Physical Review Letters 87, 088102-1. Hamacher, Trylska, McCammon (2006)PLoS Computational Biology 2, e10. Hamacher (2009) Eur. Biophys. J., in press.

Examples

Run this code
p<-extractPDB(system.file("1KZK.pdb", package = "BioPhysConnectoR"))
cm<-build.contacts(n = p$lca, xyz = p$coords, cuts = 169)$cm
chains<-p$chains
im<-build.interact(cseq=p$caseq,d=chains,mj1=matrix(0.05,20,20),alpha=1)
res<-scpcp(cm = cm, maxtol = 10^(-10), T = 5, R = 0.8, im = im, 
	   maxiter = 10, pstart = 0.5, chains=chains)

Run the code above in your browser using DataLab